@@ -1,7 +1,9 @@
 '''扫描当前所有matcher，总结命令'''
-import json
-from random import sample
 import re
+import json
+from loguru import logger
+from asyncio import sleep
+from random import sample
 from itertools import chain
 from nonebot.matcher import matchers, Matcher
 from nonebot.rule import CommandRule, RegexRule, EndswithRule, KeywordsRule, FullmatchRule, StartswithRule, ShellCommandRule, ToMeRule
@@ -10,13 +12,22 @@ from ayaka import AyakaCat, resource_download, bridge
 
 cat = AyakaCat("命令探查")
 pt = re.compile(r"nonebot[_-]plugin[_-]")
+pt2 = re.compile(r"^plugins(_test)?\.")
 plugins: list["PluginInfo"] = []
 nb_shop_data: list["NbShopPluginInfo"] = []
 
 
+def short_name(name: str):
+    name = pt2.sub("", name)
+    name = name.split(".")[0]
+    name = pt.sub("", name)
+    return name
+
+
 @bridge.on_startup
 async def download():
     nb_shop_data.clear()
+    logger.info("nb商店数据更新中...")
     try:
         data = await resource_download("https://raw.githubusercontent.com/nonebot/nonebot2/master/website/static/plugins.json")
     except:
@@ -25,6 +36,7 @@ async def download():
         data = json.loads(data)
         for d in data:
             nb_shop_data.append(NbShopPluginInfo(**d))
+        logger.info("nb商店数据更新完毕")
 
 
 class NbShopPluginInfo(BaseModel):
@@ -71,7 +83,7 @@ class HandlerInfo(BaseModel):
         return info
 
     def get_info(self):
-        info = f"[{self.module}].{self.name}"
+        info = self.name
         if self.doc:
             info += f"({self.doc})"
         return info
@@ -87,18 +99,18 @@ class MatcherInfo(BaseModel):
             if len(self.rules) == 1:
                 items.append(f"规则：{self.rules[0].get_info()}")
             else:
-                items.append("规则：")
+                items.append("多规则：")
                 for r in self.rules:
-                    items.append(r.get_info())
+                    items.append("  " + r.get_info())
 
         handlers = [h for h in self.handlers if h.is_useful()]
         if handlers:
             if len(handlers) == 1:
                 items.append(f"回调：{handlers[0].get_info()}")
             else:
-                items.append("回调：")
+                items.append("多回调：")
                 for h in handlers:
-                    items.append(h.get_info())
+                    items.append("  " + h.get_info())
 
         return "\n".join(items)
 
@@ -106,14 +118,27 @@ class MatcherInfo(BaseModel):
 class PluginInfo(BaseModel):
     name: str = ""
     matchers: list[MatcherInfo] = []
+    meta: dict = {}
 
     def get_infos(self):
-        info = f"插件名：{self.name}\nmatcher数量：{len(self.matchers)}\n以下仅显示可分析的信息"
+        info = f"插件名：{self.name}\nmatcher数量：{len(self.matchers)}"
         items = [info]
-        for m in self.matchers:
-            item = m.get_info()
-            if item not in items:
-                items.append(item)
+        if self.meta:
+            items.append("- 插件元数据 -")
+            for k, v in self.meta.items():
+                if v:
+                    if len(str(v)) < 50:
+                        items.append(f"[{k}] {v}")
+                    else:
+                        items.append(f"[{k}]\n{v}")
+
+        if self.matchers:
+            items.append("- 解析出的matcher信息 -")
+            for m in self.matchers:
+                item = m.get_info()
+                if item not in items:
+                    items.append(item)
+
         return items
 
 
@@ -128,13 +153,19 @@ def get_plugin(plugin_name: str, auto_create: bool = True):
     return plugin
 
 
-def scan_all():
+async def scan_all():
     plugins.clear()
     ms = list(chain(*matchers.values()))
     for m in ms:
-        name = pt.sub("", m.module_name)
+        name = short_name(m.module_name)
         plugin = get_plugin(name)
+        if not plugin.meta:
+            meta = getattr(m.module, "__plugin_meta__", None)
+            if meta:
+                plugin.meta = vars(meta)
         plugin.matchers.append(scan_matcher(m))
+        await sleep(0)
+    plugins.sort(key=lambda x: x.name)
 
 
 def scan_matcher(matcher: Matcher):
@@ -152,7 +183,7 @@ def scan_handler(func):
     if func.__doc__:
         doc = func.__doc__
     return HandlerInfo(
-        module=pt.sub("", func.__module__),
+        module=short_name(func.__module__),
         name=func.__name__,
         doc=doc,
     )
@@ -186,7 +217,7 @@ def scan_checker(func):
             args=[func.msg]
         )
 
-    return RuleInfo(type="未知规则")
+    return RuleInfo(type="[未知]")
 
 
 cat.set_rest_cmds(cmds={"exit", "退出"})
@@ -197,8 +228,8 @@ async def scan_handle():
     '''唤醒猫猫，并扫描全部matchers'''
     await cat.wakeup()
     await cat.send_help()
-    scan_all()
-    await cat.send("已完成扫描")
+    await scan_all()
+    await show_all_plugin_names()
 
 
 @cat.on_cmd(cmds="列表", states="*")
@@ -211,13 +242,13 @@ async def show_all_plugin_names():
 @cat.on_cmd(cmds="查看", states="*")
 async def show_plugin_info():
     '''<编号>/<插件名> 展示插件信息'''
-    if cat.params.nums:
-        n = cat.params.nums[0]
+    if cat.nums:
+        n = cat.nums[0]
         if n < 0 or n >= len(plugins):
             return await cat.send("超出范围了呢")
         plugin = plugins[n]
     else:
-        plugin = get_plugin(cat.params.arg, False)
+        plugin = get_plugin(cat.arg, False)
         if not plugin:
             return await cat.send("没有这个插件呢")
 
@@ -233,13 +264,13 @@ async def show_plugin_info_in_shop():
         await cat.send("下载成功，请重新发送指令")
         return
 
-    if cat.params.nums:
-        n = cat.params.nums[0]
+    if cat.nums:
+        n = cat.nums[0]
         if n < 0 or n >= len(plugins):
             return await cat.send("超出范围了呢")
         name = plugins[n].name
     else:
-        name = cat.params.arg
+        name = cat.arg
 
     ps = [p for p in nb_shop_data if p.relative(name)]
     if not ps:
